# CBPi4 Buzzer Plugin

## Buzzer Plugin calls buzzer on cbpi notifications

- Settings will be added by this plugin
- buzzer_gpio: GPIO your buzzer is conected to
- buzzer_level: Sound level(High or Low)
- Different sounds for error, warning and other message types

-  Changelog

**01.04.2021:

- Initial release
